<?php

namespace Litecms\Career\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Career\Http\Requests\CareerResumeRequest;
use Litecms\Career\Interfaces\CareerResumeRepositoryInterface;
use Litecms\Career\Models\CareerResume;

/**
 * Resource controller class for career_resume.
 */
class CareerResumeResourceController extends BaseController
{

    /**
     * Initialize career_resume resource controller.
     *
     * @param type CareerResumeRepositoryInterface $career_resume
     *
     * @return null
     */
    public function __construct(CareerResumeRepositoryInterface $career_resume)
    {
        parent::__construct();
        $this->repository = $career_resume;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Career\Repositories\Criteria\CareerResumeResourceCriteria::class);
    }

    /**
     * Display a list of career_resume.
     *
     * @return Response
     */
    public function index(CareerResumeRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Career\Repositories\Presenter\CareerResumePresenter::class)
                ->$function();
        }

        $career_resumes = $this->repository->paginate();

        return $this->response->title(trans('career::career_resume.names'))
            ->view('career::career_resume.index', true)
            ->data(compact('career_resumes'))
            ->output();
    }

    /**
     * Display career_resume.
     *
     * @param Request $request
     * @param Model   $career_resume
     *
     * @return Response
     */
    public function show(CareerResumeRequest $request, CareerResume $career_resume)
    {

        if ($career_resume->exists) {
            $view = 'career::career_resume.show';
        } else {
            $view = 'career::career_resume.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('career::career_resume.name'))
            ->data(compact('career_resume'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new career_resume.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(CareerResumeRequest $request)
    {

        $career_resume = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('career::career_resume.name')) 
            ->view('career::career_resume.create', true) 
            ->data(compact('career_resume'))
            ->output();
    }

    /**
     * Create new career_resume.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(CareerResumeRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $career_resume                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('career::career_resume.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('career/career_resume/' . $career_resume->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/career/career_resume'))
                ->redirect();
        }

    }

    /**
     * Show career_resume for editing.
     *
     * @param Request $request
     * @param Model   $career_resume
     *
     * @return Response
     */
    public function edit(CareerResumeRequest $request, CareerResume $career_resume)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('career::career_resume.name'))
            ->view('career::career_resume.edit', true)
            ->data(compact('career_resume'))
            ->output();
    }

    /**
     * Update the career_resume.
     *
     * @param Request $request
     * @param Model   $career_resume
     *
     * @return Response
     */
    public function update(CareerResumeRequest $request, CareerResume $career_resume)
    {
        try {
            $attributes = $request->all();

            $career_resume->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('career::career_resume.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('career/career_resume/' . $career_resume->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('career/career_resume/' . $career_resume->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the career_resume.
     *
     * @param Model   $career_resume
     *
     * @return Response
     */
    public function destroy(CareerResumeRequest $request, CareerResume $career_resume)
    {
        try {

            $career_resume->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('career::career_resume.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('career/career_resume/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('career/career_resume/' . $career_resume->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple career_resume.
     *
     * @param Model   $career_resume
     *
     * @return Response
     */
    public function delete(CareerResumeRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('career::career_resume.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('career/career_resume'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/career/career_resume'))
                ->redirect();
        }

    }

    /**
     * Restore deleted career_resumes.
     *
     * @param Model   $career_resume
     *
     * @return Response
     */
    public function restore(CareerResumeRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('career::career_resume.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/career/career_resume'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/career/career_resume/'))
                ->redirect();
        }

    }

}
