<?php

namespace Litecms\Career\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Career\Models\CareerJob;

class CareerJobPolicy
{

    /**
     * Determine if the given user can view the career_job.
     *
     * @param UserPolicy $user
     * @param CareerJob $career_job
     *
     * @return bool
     */
    public function view(UserPolicy $user, CareerJob $career_job)
    {
        if ($user->canDo('career.career_job.view') && $user->isAdmin()) {
            return true;
        }

        return $career_job->user_id == user_id() && $career_job->user_type == user_type();
    }

    /**
     * Determine if the given user can create a career_job.
     *
     * @param UserPolicy $user
     * @param CareerJob $career_job
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('career.career_job.create');
    }

    /**
     * Determine if the given user can update the given career_job.
     *
     * @param UserPolicy $user
     * @param CareerJob $career_job
     *
     * @return bool
     */
    public function update(UserPolicy $user, CareerJob $career_job)
    {
        if ($user->canDo('career.career_job.edit') && $user->isAdmin()) {
            return true;
        }

        return $career_job->user_id == user_id() && $career_job->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given career_job.
     *
     * @param UserPolicy $user
     * @param CareerJob $career_job
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, CareerJob $career_job)
    {
        return $career_job->user_id == user_id() && $career_job->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given career_job.
     *
     * @param UserPolicy $user
     * @param CareerJob $career_job
     *
     * @return bool
     */
    public function verify(UserPolicy $user, CareerJob $career_job)
    {
        if ($user->canDo('career.career_job.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given career_job.
     *
     * @param UserPolicy $user
     * @param CareerJob $career_job
     *
     * @return bool
     */
    public function approve(UserPolicy $user, CareerJob $career_job)
    {
        if ($user->canDo('career.career_job.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
