<?php

namespace Litecms\Career\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Career\Models\CareerResume;

class CareerResumePolicy
{

    /**
     * Determine if the given user can view the career_resume.
     *
     * @param UserPolicy $user
     * @param CareerResume $career_resume
     *
     * @return bool
     */
    public function view(UserPolicy $user, CareerResume $career_resume)
    {
        if ($user->canDo('career.career_resume.view') && $user->isAdmin()) {
            return true;
        }

        return $career_resume->user_id == user_id() && $career_resume->user_type == user_type();
    }

    /**
     * Determine if the given user can create a career_resume.
     *
     * @param UserPolicy $user
     * @param CareerResume $career_resume
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('career.career_resume.create');
    }

    /**
     * Determine if the given user can update the given career_resume.
     *
     * @param UserPolicy $user
     * @param CareerResume $career_resume
     *
     * @return bool
     */
    public function update(UserPolicy $user, CareerResume $career_resume)
    {
        if ($user->canDo('career.career_resume.edit') && $user->isAdmin()) {
            return true;
        }

        return $career_resume->user_id == user_id() && $career_resume->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given career_resume.
     *
     * @param UserPolicy $user
     * @param CareerResume $career_resume
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, CareerResume $career_resume)
    {
        return $career_resume->user_id == user_id() && $career_resume->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given career_resume.
     *
     * @param UserPolicy $user
     * @param CareerResume $career_resume
     *
     * @return bool
     */
    public function verify(UserPolicy $user, CareerResume $career_resume)
    {
        if ($user->canDo('career.career_resume.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given career_resume.
     *
     * @param UserPolicy $user
     * @param CareerResume $career_resume
     *
     * @return bool
     */
    public function approve(UserPolicy $user, CareerResume $career_resume)
    {
        if ($user->canDo('career.career_resume.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
